@@ -24,12 +24,17 @@ THE SOFTWARE.
 """
 
 
-from pudb.settings import load_config
+import re
 import sys
+from importlib import metadata
+
+from pudb.settings import load_config
 
 
-NUM_VERSION = (2022, 1, 2)
-VERSION = ".".join(str(nv) for nv in NUM_VERSION)
+VERSION = metadata.version("pudb")
+_ver_match = re.match("^([0-9.]+)([a-z0-9]*?)$", VERSION)
+assert _ver_match
+NUM_VERSION = tuple(int(nr) for nr in _ver_match.group(1).split("."))
 __version__ = VERSION
 
 
@@ -54,6 +59,8 @@ class PudbShortcuts:
 
 
 import builtins
+
+
 builtins.__dict__["pu"] = PudbShortcuts()
 
 
@@ -80,6 +87,7 @@ def _get_debugger(**kwargs):
             kwargs.setdefault("stdin", tty_file)
             kwargs.setdefault("stdout", tty_file)
             kwargs.setdefault("term_size", term_size)
+            kwargs.setdefault("tty_file", tty_file)
 
         from pudb.debugger import Debugger
         dbg = Debugger(**kwargs)
@@ -90,8 +98,12 @@ def _get_debugger(**kwargs):
 
 
 def _have_debugger():
-    from pudb.debugger import Debugger
-    return bool(Debugger._current_debugger)
+    try:
+        from pudb.debugger import Debugger
+        return bool(Debugger._current_debugger)
+    except ImportError:
+        # Import cycles may happen if function is called during early startup
+        return False
 
 
 import signal  # noqa
@@ -104,9 +116,19 @@ def runmodule(*args, **kwargs):
     runscript(*args, **kwargs)
 
 
-def runscript(mainpyfile, args=None, pre_run="", steal_output=False,
-              run_as_module=False):
-    dbg = _get_debugger(steal_output=steal_output)
+def runscript(mainpyfile, steal_output=False, _continue_at_start=False,
+              **kwargs):
+    try:
+        dbg = _get_debugger(
+            steal_output=steal_output,
+            _continue_at_start=_continue_at_start,
+        )
+        _runscript(mainpyfile, dbg, **kwargs)
+    finally:
+        dbg.__del__()
+
+
+def _runscript(mainpyfile, dbg, args=None, pre_run="", run_as_module=False):
 
     # Note on saving/restoring sys.argv: it's a good idea when sys.argv was
     # modified by the script being debugged. It's a bad idea when it was
@@ -122,11 +144,17 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False,
             sys.argv = [mainpyfile] + args
 
     # replace pudb's dir with script's dir in front of module search path.
-    from os.path import dirname
+    from pathlib import Path
     prev_sys_path = sys.path[:]
-    sys.path[0] = dirname(mainpyfile)
+    sys.path[0] = str(Path(mainpyfile).resolve().parent)
+
+    import os
+    cwd = os.getcwd()
 
     while True:
+        # Script may have changed directory. Restore cwd before restart.
+        os.chdir(cwd)
+
         if pre_run:
             from subprocess import call
             retcode = call(pre_run, close_fds=True, shell=True)
@@ -173,7 +201,6 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False,
                     ])),
                 [
                     ("Restart", "restart"),
-                    ("Examine", "examine"),
                     ("Quit", "quit"),
                     ],
                 focus_buttons=True,
@@ -181,16 +208,11 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False,
                 title="Finished",
                 extra_bindings=[
                     ("q", "quit"),
-                    ("esc", "examine"),
                     ])
 
             if result == "quit":
                 return
 
-            if result == "examine":
-                dbg.post_mortem = True
-                dbg.interaction(None, sys.exc_info(), show_exc_dialog=False)
-
             if result == "restart":
                 break
 
@@ -278,23 +300,26 @@ def set_interrupt_handler(interrupt_signal=None):
             old_handler = "not installed from python"
         return warn("A non-default handler for signal %d is already installed (%s). "
                 "Skipping pudb interrupt support."
-                % (interrupt_signal, old_handler))
+                % (interrupt_signal, old_handler),
+                stacklevel=2)
 
     import threading
     if not isinstance(threading.current_thread(), threading._MainThread):
         from warnings import warn
         # Setting signals from a non-main thread will not work
         return warn("Setting the interrupt handler can only be done on the main "
-                "thread. The interrupt handler was NOT installed.")
+                "thread. The interrupt handler was NOT installed.",
+                stacklevel=2)
 
     try:
         signal.signal(interrupt_signal, _interrupt_handler)
     except ValueError:
-        from traceback import format_exception
         import sys
+        from traceback import format_exception
         from warnings import warn
         warn("setting interrupt handler on signal %d failed: %s"
-                % (interrupt_signal, "".join(format_exception(*sys.exc_info()))))
+                % (interrupt_signal, "".join(format_exception(*sys.exc_info()))),
+                stacklevel=2)
 
 
 def post_mortem(tb=None, e_type=None, e_value=None):
@@ -311,7 +336,7 @@ def post_mortem(tb=None, e_type=None, e_value=None):
 
 def pm():
     import sys
-    exc_type, exc_val, tb = sys.exc_info()
+    exc_type, _exc_val, _tb = sys.exc_info()
 
     if exc_type is None:
         # No exception on record. Do nothing.
