@@ -26,16 +26,18 @@ THE SOFTWARE.
 
 # {{{ constants and imports
 
-import urwid
 import inspect
 import warnings
-
 from abc import ABC, abstractmethod
 from collections.abc import Callable, Sized
-from typing import Tuple, List
+from typing import List, Tuple
+
+import urwid
+
 from pudb.lowlevel import ui_log
 from pudb.ui_tools import text_width
 
+
 try:
     import numpy
     HAVE_NUMPY = 1
@@ -47,7 +49,7 @@ except ImportError:
 
 # {{{ abstract base classes for containers
 
-class PudbCollection(ABC):
+class PudbCollection(ABC):  # noqa: B024
     @classmethod
     def __subclasshook__(cls, c):
         if cls is PudbCollection:
@@ -80,7 +82,7 @@ class PudbCollection(ABC):
         return len(collection)
 
 
-class PudbSequence(ABC):
+class PudbSequence(ABC):  # noqa: B024
     @classmethod
     def __subclasshook__(cls, c):
         if cls is PudbSequence:
@@ -113,7 +115,7 @@ class PudbSequence(ABC):
         return len(sequence)
 
 
-class PudbMapping(ABC):
+class PudbMapping(ABC):  # noqa: B024
     @classmethod
     def __subclasshook__(cls, c):
         if cls is PudbMapping:
@@ -210,11 +212,15 @@ class WatchEvalError:
 
 # {{{ widget
 
-class VariableWidget(urwid.FlowWidget):
+class VariableWidget(urwid.Widget):
+    _sizing = frozenset([urwid.Sizing.FLOW])
+
     PREFIX = "| "
 
     def __init__(self, parent, var_label, value_str, id_path,
             attr_prefix=None, watch_expr=None, iinfo=None):
+        super().__init__()
+
         assert isinstance(id_path, str)
         self.parent = parent
         self.nesting_level = 0 if parent is None else parent.nesting_level + 1
@@ -298,7 +304,7 @@ class VariableWidget(urwid.FlowWidget):
 
             extralabel_full, extralabel_rem = divmod(
                     text_width(var_label[maxcol:]), maxcol)
-            totallen = sum([text_width(i) for i in text])
+            totallen = sum(text_width(i) for i in text)
             labellen = (
                     len(self.prefix)  # Padding of first line
 
@@ -353,7 +359,7 @@ class VariableWidget(urwid.FlowWidget):
             attr = [[(apfx+"label", lprefix + text_width(self.var_label)), ]]
 
         # Ellipses to show text was cut off
-        #encoding = urwid.util.detected_encoding
+        # encoding = urwid.util.detected_encoding
 
         for i in range(len(text)):
             if text_width(text[i]) > maxcol:
